spoon.ber.stream.BERStream

Package spoon :: Package ber :: Module stream :: Class BERStream |
[hide private]
[frames] | no frames]

# Class BERStream

source code

    object --+
             |
            BERStream

FIXME docs

Instance Methods | [hide private]
`` | __init__(self, fd, size=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | _next_tag(self)
`` | has_next(self) Return `True` if there is still more data left in this stream, and a future call to next should succeed.
`object` | next(self) Return the next item from this stream.
`` | add(self, item, compress=False) Write an object into the stream.
`` | _add_eof(self)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Static Methods | [hide private]
`` | _get_encoder(item, compress=False)
`` | can_encode(item)

Class Variables | [hide private]
`` | _encoder_table = `{}`
`` | _zencoder_table = `{}`
`` | _decoder_table = `{}`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, fd, size=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### _next_tag(self) | source code
None

### has_next(self) | source code
Return `True` if there is still more data left in this stream, and a future call to next should succeed. Returns: `True` if the stream has more data to read

### next(self) | source code
Return the next item from this stream. Objects are decoded using the codecs registered via the decoder operator, though simple types (None, bool, int, long, str, unicode, list, and tuple) have default decoders. Returns: `object` the next object from the stream Raises: `BERException` - if you're already at the end of the stream

### add(self, item, compress=False) | source code
Write an object into the stream. Simple types (None, bool, int, long, str, unicode, list, and tuple) are handled by default encoders. Other encoders may be added with the encoder decorator. Parameters: `item` (`object`) - object to add

### _add_eof(self) | source code
None

### _get_encoder(item, compress=False) Static Method | source code
None Decorators:

### can_encode(item) Static Method | source code
None Decorators:

Class Variable Details | [hide private]

    ### _encoder_table None Value:
        {}

    ### _zencoder_table None Value:
        {}

    ### _decoder_table None Value:
        {}